(12)

(54)

(75)

(73)

( * )

(21)

(22)

(86)

(87)

(65)

(30)

(51)

(52)

United States Patent Bernard et al.

POLYISOCYANATE COMPOSITION HAVING IMPROVED IMPACT-PROOF PROPERTIES

Inventors: Jean-Marie Bernard, Saint Laurent d'Agny (FR); Mathias Dubecq, Lyons (FR)

Assignee: Rhodia Chimie, Aubervilliers (FR)

Notice: Subject to any disclaimer, the term of this patent is extended or adjusted under 35 U.S.C. 154(b) by 992 days.

Appl. No.: 11/793,489

PCT Filed: Dec. 20, 2005

PCT No.: PCT/FR2005/003197

§ 371 (c)(1),

(2), (4) Date: Oct. 29, 2007

PCT Pub. No.: WO2006/067326

PCT Pub. No.: WO2006/067326

PCT Pub. Date: Jun. 29, 2006

Prior Publication Data

US 2008/0044578 A1 Feb. 21, 2008

Foreign Application Priority Data

Dec. 21, 2004 (FR) ................................... 04 13669

Int. Cl.

C08K 5/00 (2006.01)

U.S. Cl. .................... 524/123 ; 427/385.5; 526/310;

U.S. Cl. .................... 524/123 ; 427/385.5; 526/310;

528/44; 528/45; 528/68

US008188171B2

(10) Patent No.:

US 8,188,171 B2

(45) Date of Patent:

May 29, 2012

(58) Field of Classification Search ................... 524/123 See application file for complete search history.

## (56) References Cited

U.S. PATENT DOCUMENTS

5,877,254 A * 3/1999 La Casse et al. ............ 524/590 5,977,246 A * 11/1999 Fenn .......................... 524/590 6,217,941 B1 * 4/2001 Bernard et al. ................ 427/358 6,509,396 B1 * 1/2003 Hoppe et al. ................... 524/35 2001/0021746 A1 9/2001 Nabavi et al. 2004/0242833 A1 12/2004 Bernard

## FOREIGN PATENT DOCUMENTS

DE

EP

FR

GB

JP

JP

JP

WO

197 25 507 1 074 590 A 2 243 983 A 1 487 563 08-176477 2001-323123 2003-292887 01/05861 A1

12/1998 2/2001 4/1975 10/1977 7/1996 11/2001 10/2003 1/2001

* cited by examiner

Primary Examiner - Doris Lee

(74) Attorney, Agent, or Firm - Buchanan Ingersoll &amp; Rooney PC

## (57) ABSTRACT

The invention relates to the use of additived (poly)isocyanate compositions for producing coatings, especially paints or varnishes for car bodywork parts, said compositions having excellent impact-resistant properties, especially grit-resistant properties.

36 Claims, No Drawings